@@ -9,13 +9,20 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QDebug>
+#include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQmlEngine>
+#include <QStandardPaths>
 
 // Frameworks
+#include <KAboutData>
 #include <KConfigGroup>
+#include <KCrash>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
+
+// Plasma
 #include <Plasma/Theme>
 
 // Own
@@ -23,6 +30,8 @@
 #include "iconmodel.h"
 #include "sortfiltermodel.h"
 
+using namespace Qt::Literals;
+
 void messageOutput(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
     if ((msg.contains("qt.svg") && msg.contains("Could not resolve property: #linearGradient")) || msg.contains("Could not resolve property: #pattern")) {
@@ -58,11 +67,11 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("iconexplorer");
 
-    app.setApplicationVersion(PROJECT_VERSION);
-    app.setDesktopFileName(QStringLiteral("org.kde.iconexplorer"));
-    app.setOrganizationName("KDE");
-    app.setOrganizationDomain("org.kde");
-    app.setApplicationName("Icon Explorer");
+    KAboutData about(u"iconexplorer"_s, i18n("Icon Explorer"), PROJECT_VERSION);
+    KAboutData::setApplicationData(about);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.iconexplorer")));
+
+    KCrash::initialize();
 
     const static auto _category = QStringLiteral("category");
     QCommandLineOption category = QCommandLineOption(QStringList() << QStringLiteral("c") << _category, i18n("Start with category"), i18n("category"));
@@ -85,9 +94,20 @@ int main(int argc, char **argv)
 
     QString _cc = parser.value(category);
 
+    // Clean up old config files
+    const QString configFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, "KDE/Icon Explorer.conf");
+    if (!configFile.isEmpty()) {
+        QFile::remove(configFile);
+    }
+
+    const QString oldConfigFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, "KDE/Cuttlefish.conf");
+    if (!oldConfigFile.isEmpty()) {
+        QFile::remove(oldConfigFile);
+    }
+
     QQmlApplicationEngine engine;
 
-    auto l10nContext = new KLocalizedContext(&engine);
+    auto l10nContext = new KLocalizedQmlContext(&engine);
     l10nContext->setTranslationDomain(QStringLiteral("iconexplorer"));
     engine.rootContext()->setContextObject(l10nContext);
 
