@@ -25,8 +25,8 @@
 class ViewerCorona : public Plasma::Corona
 {
 public:
-    ViewerCorona()
-        : Plasma::Corona()
+    ViewerCorona(QObject *parent)
+        : Plasma::Corona(parent)
         , m_view(nullptr)
     {
     }
@@ -143,7 +143,7 @@ void View::addContainment(const QString &cont)
 
     setContainment(c);
 
-    connect(containment(), &Plasma::Containment::appletRemoved, [=](Plasma::Applet *applet) {
+    connect(containment(), &Plasma::Containment::appletRemoved, [this](Plasma::Applet *applet) {
         if (applet && applet->pluginMetaData().isValid()) {
             addApplet(applet->pluginMetaData().pluginId());
         }
@@ -282,12 +282,12 @@ void View::changeLocation(int location)
     addLocation(locationType);
 }
 
-ViewerCorona *View::createCorona()
+ViewerCorona *View::createCorona(QObject *parent)
 {
     KPackage::Package package = KPackage::PackageLoader::self()->loadPackage("Plasma/Shell");
     package.setPath("org.kde.plasma.plasmoidviewershell");
 
-    ViewerCorona *cor = new ViewerCorona();
+    ViewerCorona *cor = new ViewerCorona(parent);
     cor->setKPackage(package);
 
     return cor;
